==> haskell-unliftio-core-0.2.0.1-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unliftio-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unliftio-core
version:              0.2.0.1
visibility:           public
id:                   unliftio-core-0.2.0.1-2baD1vXgUkB5a1NRn2rSLN
key:                  unliftio-core-0.2.0.1-2baD1vXgUkB5a1NRn2rSLN
license:              MIT
copyright:            2017-2020 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Francesco Mazzoli
homepage:
    https://github.com/fpco/unliftio/tree/master/unliftio-core#readme

synopsis:             The MonadUnliftIO typeclass for unlifting monads to IO
description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio-core>

category:             Control
abi:                  43790fdf8664e56bb0d05d83ceb88f78
exposed:              True
exposed-modules:      Control.Monad.IO.Unlift
hidden-modules:       Paths_unliftio_core
import-dirs:          /usr/lib/ghc-9.0.1/site-local/unliftio-core-0.2.0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/unliftio-core-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/unliftio-core-0.2.0.1
hs-libraries:         HSunliftio-core-0.2.0.1-2baD1vXgUkB5a1NRn2rSLN
depends:              base-4.15.0.0 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-unliftio-core/html/unliftio-core.haddock

haddock-html:         /usr/share/doc/haskell-unliftio-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unliftio-core-0.2.0.1-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unliftio-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unliftio-core
version:              0.2.0.1
visibility:           public
id:                   unliftio-core-0.2.0.1-HjGpVpPktr5Bc3kYrL6LtS
key:                  unliftio-core-0.2.0.1-HjGpVpPktr5Bc3kYrL6LtS
license:              MIT
copyright:            2017-2020 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Francesco Mazzoli
homepage:
    https://github.com/fpco/unliftio/tree/master/unliftio-core#readme

synopsis:             The MonadUnliftIO typeclass for unlifting monads to IO
description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio-core>

category:             Control
abi:                  b7ddcf670e5183647b4b78dfe1b6ee1c
exposed:              True
exposed-modules:      Control.Monad.IO.Unlift
hidden-modules:       Paths_unliftio_core
import-dirs:          /usr/lib/ghc-9.0.2/site-local/unliftio-core-0.2.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/unliftio-core-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/unliftio-core-0.2.0.1
hs-libraries:         HSunliftio-core-0.2.0.1-HjGpVpPktr5Bc3kYrL6LtS
depends:              base-4.15.1.0 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-unliftio-core/html/unliftio-core.haddock

haddock-html:         /usr/share/doc/haskell-unliftio-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
